@@ -104,10 +104,7 @@
 #include "DjVuFile.h"
 #include "GOS.h"
 #include "DjVuMessage.h"
-#include <locale.h>
-#include <stddef.h>
-#include <stdlib.h>
-
+#include "common.h"
 
 struct DejaVuInfo
 {
@@ -207,9 +204,7 @@ usage()
 int
 main(int argc, char **argv)
 {
-  setlocale(LC_ALL,"");
-  setlocale(LC_NUMERIC,"C");
-  djvu_programname(argv[0]);
+  DJVU_LOCALE;
   GArray<GUTF8String> dargv(0,argc-1);
   for(int i=0;i<argc;++i)
     dargv[i]=GNativeString(argv[i]);
